complete -c uu-hostname -s d -l domain -d 'Display the name of the DNS domain if possible'
complete -c uu-hostname -s i -l ip-address -d 'Display the network address(es) of the host'
complete -c uu-hostname -s f -l fqdn -d 'Display the FQDN (Fully Qualified Domain Name) (default)'
complete -c uu-hostname -s s -l short -d 'Display the short hostname (the portion before the first dot) if possible'
complete -c uu-hostname -s h -l help -d 'Print help'
complete -c uu-hostname -s V -l version -d 'Print version'
