complete -c uu-uniq -s D -l all-repeated -d 'print all duplicate lines. Delimiting is done with blank lines. [default: none]' -r -f -a "{none	,prepend	,separate	}"
complete -c uu-uniq -l group -d 'show all items, separating groups with an empty line. [default: separate]' -r -f -a "{separate	,prepend	,append	,both	}"
complete -c uu-uniq -s w -l check-chars -d 'compare no more than N characters in lines' -r
complete -c uu-uniq -s s -l skip-chars -d 'avoid comparing the first N characters' -r
complete -c uu-uniq -s f -l skip-fields -d 'avoid comparing the first N fields' -r
complete -c uu-uniq -s 0 -r
complete -c uu-uniq -s 1 -r
complete -c uu-uniq -s 2 -r
complete -c uu-uniq -s 3 -r
complete -c uu-uniq -s 4 -r
complete -c uu-uniq -s 5 -r
complete -c uu-uniq -s 6 -r
complete -c uu-uniq -s 7 -r
complete -c uu-uniq -s 8 -r
complete -c uu-uniq -s 9 -r
complete -c uu-uniq -s c -l count -d 'prefix lines by the number of occurrences'
complete -c uu-uniq -s i -l ignore-case -d 'ignore differences in case when comparing'
complete -c uu-uniq -s d -l repeated -d 'only print duplicate lines'
complete -c uu-uniq -s u -l unique -d 'only print unique lines'
complete -c uu-uniq -s z -l zero-terminated -d 'end lines with 0 byte, not newline'
complete -c uu-uniq -s h -l help -d 'Print help'
complete -c uu-uniq -s V -l version -d 'Print version'
