complete -c uu-mkdir -s m -l mode -d 'set file mode (not implemented on windows)' -r
complete -c uu-mkdir -s p -l parents -d 'make parent directories as needed'
complete -c uu-mkdir -s v -l verbose -d 'print a message for each printed directory'
complete -c uu-mkdir -s h -l help -d 'Print help'
complete -c uu-mkdir -s V -l version -d 'Print version'
