complete -c uu-env -s C -l chdir -d 'change working directory to DIR' -r -f -a "(__fish_complete_directories)"
complete -c uu-env -s f -l file -d 'read and set variables from a ".env"-style configuration file (prior to any unset and/or set)' -r -F
complete -c uu-env -s u -l unset -d 'remove variable from the environment' -r
complete -c uu-env -s i -l ignore-environment -d 'start with an empty environment'
complete -c uu-env -s 0 -l null -d 'end each output line with a 0 byte rather than a newline (only valid when printing the environment)'
complete -c uu-env -s h -l help -d 'Print help'
complete -c uu-env -s V -l version -d 'Print version'
