complete -c uu-pr -l pages -d 'Begin and stop printing with page FIRST_PAGE[:LAST_PAGE]' -r
complete -c uu-pr -s h -l header -d 'Use the string header to replace the file name in the header line.' -r
complete -c uu-pr -s n -l number-lines -d 'Provide width digit line numbering.  The default for width, if not specified, is 5.  The number occupies the first width column positions of each text column or each line of -m output.  If char (any non-digit character) is given, it is appended to the line number to separate it from whatever follows.  The default for char is a <tab>. Line numbers longer than width columns are truncated.' -r
complete -c uu-pr -s N -l first-line-number -d 'start counting with NUMBER at 1st line of first page printed' -r
complete -c uu-pr -s l -l length -d 'Override the 66-line default (default number of lines of text 56, and with -F 63) and reset the page length to lines.  If lines is not greater than the sum  of  both the  header  and trailer depths (in lines), the pr utility shall suppress both the header and trailer, as if the -t option were in effect. ' -r
complete -c uu-pr -s w -l width -d 'Set the width of the line to width column positions for multiple text-column output only. If the -w option is not specified and the -s option is not specified, the default width shall be 72. If the -w option is not specified and the -s option is specified, the default width shall be 512.' -r
complete -c uu-pr -s W -l page-width -d 'set page width to PAGE_WIDTH (72) characters always, truncate lines, except -J option is set, no interference with -S or -s' -r
complete -c uu-pr -l column -d 'Produce multi-column output that is arranged in column columns (the default shall be 1) and is written down each column  in  the order in which the text is received from the input file. This option should not be used with -m. The options -e and -i shall be assumed for multiple text-column output.  Whether or not text columns are produced with identical vertical lengths is unspecified, but a text column shall never exceed the length of the page (see the -l option). When used with -t, use the minimum number of lines to write the output.' -r
complete -c uu-pr -s s -l separator -d 'Separate text columns by the single character char instead of by the appropriate number of <space>s (default for char is the <tab> character).' -r
complete -c uu-pr -s S -l sep-string -d 'separate columns by STRING, without -S: Default separator <TAB> with -J and <space> otherwise (same as -S" "), no effect on column options' -r
complete -c uu-pr -s o -l indent -d 'Each line of output shall be preceded by offset <space>s. If the -o option is not specified, the default offset shall be zero. The space taken is in addition to the output line width (see the -w option below).' -r
complete -c uu-pr -s d -l double-space -d 'Produce output that is double spaced. An extra <newline> character is output following every <newline> found in the input.'
complete -c uu-pr -s t -l omit-header -d 'Write neither the five-line identifying header nor the five-line trailer usually supplied for each page. Quit writing after the last line of each file without spacing to the end of the page.'
complete -c uu-pr -s r -l no-file-warnings -d 'omit warning when a file cannot be opened'
complete -c uu-pr -s F -l form-feed -d 'Use a <form-feed> for new pages, instead of the default behavior that uses a sequence of <newline>s.'
complete -c uu-pr -s a -l across -d 'Modify the effect of the - column option so that the columns are filled across the page in a  round-robin  order (for example, when column is 2, the first input line heads column 1, the second heads column 2, the third is the second line in column 1, and so on).'
complete -c uu-pr -s m -l merge -d 'Merge files. Standard output shall be formatted so the pr utility writes one line from each file specified by a file operand, side by side into text columns of equal fixed widths, in terms of the number of column positions. Implementations shall support merging of at least nine file operands.'
complete -c uu-pr -s J -d 'merge full lines, turns off -W line truncation, no column alignment, --sep-string[=STRING] sets separators'
complete -c uu-pr -l help -d 'Print help information'
complete -c uu-pr -s V -l version -d 'Print version'
