complete -c uu-nproc -l ignore -d 'ignore up to N cores' -r
complete -c uu-nproc -l all -d 'print the number of cores available to the system'
complete -c uu-nproc -s h -l help -d 'Print help'
complete -c uu-nproc -s V -l version -d 'Print version'
