complete -c uu-kill -s s -l signal -d 'Sends given signal instead of SIGTERM' -r
complete -c uu-kill -s l -l list -d 'Lists signals'
complete -c uu-kill -s t -l table -d 'Lists table of signals'
complete -c uu-kill -s h -l help -d 'Print help'
complete -c uu-kill -s V -l version -d 'Print version'
