complete -c uu-pinky -s l -d 'produce long format output for the specified USERs'
complete -c uu-pinky -s b -d 'omit the user\'s home directory and shell in long format'
complete -c uu-pinky -s h -d 'omit the user\'s project file in long format'
complete -c uu-pinky -s p -d 'omit the user\'s plan file in long format'
complete -c uu-pinky -s s -d 'do short format output, this is the default'
complete -c uu-pinky -s f -d 'omit the line of column headings in short format'
complete -c uu-pinky -s w -d 'omit the user\'s full name in short format'
complete -c uu-pinky -s i -d 'omit the user\'s full name and remote host in short format'
complete -c uu-pinky -s q -d 'omit the user\'s full name, remote host and idle time in short format'
complete -c uu-pinky -l help -d 'Print help information'
complete -c uu-pinky -s V -l version -d 'Print version'
