complete -c uu-more -s F -l from-line -d 'Display file beginning from line number' -r
complete -c uu-more -s n -l lines -d 'The number of lines per screen full' -r
complete -c uu-more -l number -d 'Same as --lines' -r
complete -c uu-more -s c -l print-over -d 'Do not scroll, display text and clean line ends'
complete -c uu-more -s d -l silent -d 'Display help instead of ringing bell'
complete -c uu-more -s p -l clean-print -d 'Do not scroll, clean screen and display text'
complete -c uu-more -s s -l squeeze -d 'Squeeze multiple blank lines into one'
complete -c uu-more -s u -l plain
complete -c uu-more -s h -l help -d 'Print help'
complete -c uu-more -s V -l version -d 'Print version'
