complete -c uu-who -s a -l all -d 'same as -b -d --login -p -r -t -T -u'
complete -c uu-who -s b -l boot -d 'time of last system boot'
complete -c uu-who -s d -l dead -d 'print dead processes'
complete -c uu-who -s H -l heading -d 'print line of column headings'
complete -c uu-who -s l -l login -d 'print system login processes'
complete -c uu-who -l lookup -d 'attempt to canonicalize hostnames via DNS'
complete -c uu-who -s m -d 'only hostname and user associated with stdin'
complete -c uu-who -s p -l process -d 'print active processes spawned by init'
complete -c uu-who -s q -l count -d 'all login names and number of users logged on'
complete -c uu-who -s r -l runlevel -d 'print current runlevel'
complete -c uu-who -s s -l short -d 'print only name, line, and time (default)'
complete -c uu-who -s t -l time -d 'print last system clock change'
complete -c uu-who -s u -l users -d 'list users logged in'
complete -c uu-who -s T -s w -l mesg -l message -l writable -d 'add user\'s message status as +, - or ?'
complete -c uu-who -s h -l help -d 'Print help'
complete -c uu-who -s V -l version -d 'Print version'
