complete -c uu-readlink -s f -l canonicalize -d 'canonicalize by following every symlink in every component of the given name recursively; all but the last component must exist'
complete -c uu-readlink -s e -l canonicalize-existing -d 'canonicalize by following every symlink in every component of the given name recursively, all components must exist'
complete -c uu-readlink -s m -l canonicalize-missing -d 'canonicalize by following every symlink in every component of the given name recursively, without requirements on components existence'
complete -c uu-readlink -s n -l no-newline -d 'do not output the trailing delimiter'
complete -c uu-readlink -s q -l quiet -d 'suppress most error messages'
complete -c uu-readlink -s s -l silent -d 'suppress most error messages'
complete -c uu-readlink -s v -l verbose -d 'report error message'
complete -c uu-readlink -s z -l zero -d 'separate output with NUL rather than newline'
complete -c uu-readlink -s h -l help -d 'Print help'
complete -c uu-readlink -s V -l version -d 'Print version'
