complete -c uu-sum -s r -d 'use the BSD sum algorithm, use 1K blocks (default)'
complete -c uu-sum -s s -l sysv -d 'use System V sum algorithm, use 512 bytes blocks'
complete -c uu-sum -s h -l help -d 'Print help'
complete -c uu-sum -s V -l version -d 'Print version'
