complete -c uu-echo -s n -d 'do not output the trailing newline'
complete -c uu-echo -s e -d 'enable interpretation of backslash escapes'
complete -c uu-echo -s E -d 'disable interpretation of backslash escapes (default)'
complete -c uu-echo -s h -l help -d 'Print help'
complete -c uu-echo -s V -l version -d 'Print version'
