complete -c uu-pathchk -s p -d 'check for most POSIX systems'
complete -c uu-pathchk -s P -d 'check for empty names and leading "-"'
complete -c uu-pathchk -l portability -d 'check for all POSIX systems (equivalent to -p -P)'
complete -c uu-pathchk -s h -l help -d 'Print help'
complete -c uu-pathchk -s V -l version -d 'Print version'
