complete -c uu-comm -l output-delimiter -d 'separate columns with STR' -r
complete -c uu-comm -s 1 -d 'suppress column 1 (lines unique to FILE1)'
complete -c uu-comm -s 2 -d 'suppress column 2 (lines unique to FILE2)'
complete -c uu-comm -s 3 -d 'suppress column 3 (lines that appear in both files)'
complete -c uu-comm -s z -l zero-terminated -d 'line delimiter is NUL, not newline'
complete -c uu-comm -l total -d 'output a summary'
complete -c uu-comm -s h -l help -d 'Print help'
complete -c uu-comm -s V -l version -d 'Print version'
