complete -c uu-paste -s d -l delimiters -d 'reuse characters from LIST instead of TABs' -r
complete -c uu-paste -s s -l serial -d 'paste one file at a time instead of in parallel'
complete -c uu-paste -s z -l zero-terminated -d 'line delimiter is NUL, not newline'
complete -c uu-paste -s h -l help -d 'Print help'
complete -c uu-paste -s V -l version -d 'Print version'
