complete -c uu-stdbuf -s i -l input -d 'adjust standard input stream buffering' -r
complete -c uu-stdbuf -s o -l output -d 'adjust standard output stream buffering' -r
complete -c uu-stdbuf -s e -l error -d 'adjust standard error stream buffering' -r
complete -c uu-stdbuf -s h -l help -d 'Print help'
complete -c uu-stdbuf -s V -l version -d 'Print version'
