complete -c uu-base32 -s w -l wrap -d 'wrap encoded lines after COLS character (default 76, 0 to disable wrapping)' -r
complete -c uu-base32 -s d -l decode -d 'decode data'
complete -c uu-base32 -s i -l ignore-garbage -d 'when decoding, ignore non-alphabetic characters'
complete -c uu-base32 -s h -l help -d 'Print help'
complete -c uu-base32 -s V -l version -d 'Print version'
