complete -c uu-cat -s A -l show-all -d 'equivalent to -vET'
complete -c uu-cat -s b -l number-nonblank -d 'number nonempty output lines, overrides -n'
complete -c uu-cat -s e -d 'equivalent to -vE'
complete -c uu-cat -s E -l show-ends -d 'display $ at end of each line'
complete -c uu-cat -s n -l number -d 'number all output lines'
complete -c uu-cat -s s -l squeeze-blank -d 'suppress repeated empty output lines'
complete -c uu-cat -s t -d 'equivalent to -vT'
complete -c uu-cat -s T -l show-tabs -d 'display TAB characters at ^I'
complete -c uu-cat -s v -l show-nonprinting -d 'use ^ and M- notation, except for LF (\\n) and TAB (\\t)'
complete -c uu-cat -s h -l help -d 'Print help'
complete -c uu-cat -s V -l version -d 'Print version'
