complete -c uu-hashsum -l bits -d 'set the size of the output (only for SHAKE)' -r
complete -c uu-hashsum -s b -l binary -d 'read in binary mode'
complete -c uu-hashsum -s c -l check -d 'read hashsums from the FILEs and check them'
complete -c uu-hashsum -l tag -d 'create a BSD-style checksum'
complete -c uu-hashsum -s t -l text -d 'read in text mode (default)'
complete -c uu-hashsum -s q -l quiet -d 'don\'t print OK for each successfully verified file'
complete -c uu-hashsum -s s -l status -d 'don\'t output anything, status code shows success'
complete -c uu-hashsum -l strict -d 'exit non-zero for improperly formatted checksum lines'
complete -c uu-hashsum -s w -l warn -d 'warn about improperly formatted checksum lines'
complete -c uu-hashsum -s z -l zero -d 'end each output line with NUL, not newline'
complete -c uu-hashsum -l no-names -d 'Omits filenames in the output (option not present in GNU/Coreutils)'
complete -c uu-hashsum -l md5 -d 'work with MD5'
complete -c uu-hashsum -l sha1 -d 'work with SHA1'
complete -c uu-hashsum -l sha224 -d 'work with SHA224'
complete -c uu-hashsum -l sha256 -d 'work with SHA256'
complete -c uu-hashsum -l sha384 -d 'work with SHA384'
complete -c uu-hashsum -l sha512 -d 'work with SHA512'
complete -c uu-hashsum -l sha3 -d 'work with SHA3'
complete -c uu-hashsum -l sha3-224 -d 'work with SHA3-224'
complete -c uu-hashsum -l sha3-256 -d 'work with SHA3-256'
complete -c uu-hashsum -l sha3-384 -d 'work with SHA3-384'
complete -c uu-hashsum -l sha3-512 -d 'work with SHA3-512'
complete -c uu-hashsum -l shake128 -d 'work with SHAKE128 using BITS for the output size'
complete -c uu-hashsum -l shake256 -d 'work with SHAKE256 using BITS for the output size'
complete -c uu-hashsum -l b2sum -d 'work with BLAKE2'
complete -c uu-hashsum -l b3sum -d 'work with BLAKE3'
complete -c uu-hashsum -s h -l help -d 'Print help'
complete -c uu-hashsum -s V -l version -d 'Print version'
