complete -c uu-cksum -s a -l algorithm -d 'select the digest type to use. See DIGEST below' -r -f -a "{sysv	,bsd	,crc	,md5	,sha1	,sha224	,sha256	,sha384	,sha512	,blake2b	,sm3	}"
complete -c uu-cksum -s l -l length -d 'digest length in bits; must not exceed the max for the blake2 algorithm and must be a multiple of 8' -r
complete -c uu-cksum -l untagged -d 'create a reversed style checksum, without digest type'
complete -c uu-cksum -l raw -d 'emit a raw binary digest, not hexadecimal'
complete -c uu-cksum -s h -l help -d 'Print help'
complete -c uu-cksum -s V -l version -d 'Print version'
