complete -c uu-tac -s s -l separator -d 'use STRING as the separator instead of newline' -r
complete -c uu-tac -s b -l before -d 'attach the separator before instead of after'
complete -c uu-tac -s r -l regex -d 'interpret the sequence as a regular expression'
complete -c uu-tac -s h -l help -d 'Print help'
complete -c uu-tac -s V -l version -d 'Print version'
