complete -c uu-uname -s a -l all -d 'Behave as though all of the options -mnrsvo were specified.'
complete -c uu-uname -s s -l kernel-name -d 'print the kernel name.'
complete -c uu-uname -s n -l nodename -d 'print the nodename (the nodename may be a name that the system is known by to a communications network).'
complete -c uu-uname -s r -l kernel-release -d 'print the operating system release.'
complete -c uu-uname -s v -l kernel-version -d 'print the operating system version.'
complete -c uu-uname -s m -l machine -d 'print the machine hardware name.'
complete -c uu-uname -s o -l operating-system -d 'print the operating system name.'
complete -c uu-uname -s p -l processor -d 'print the processor type (non-portable)'
complete -c uu-uname -s i -l hardware-platform -d 'print the hardware platform (non-portable)'
complete -c uu-uname -s h -l help -d 'Print help'
complete -c uu-uname -s V -l version -d 'Print version'
