complete -c uu-basename -s s -l suffix -d 'remove a trailing SUFFIX; implies -a' -r
complete -c uu-basename -s a -l multiple -d 'support multiple arguments and treat each as a NAME'
complete -c uu-basename -s z -l zero -d 'end each output line with NUL, not newline'
complete -c uu-basename -s h -l help -d 'Print help'
complete -c uu-basename -s V -l version -d 'Print version'
