complete -c uu-fold -s w -l width -d 'set WIDTH as the maximum line width rather than 80' -r
complete -c uu-fold -s b -l bytes -d 'count using bytes rather than columns (meaning control characters such as newline are not treated specially)'
complete -c uu-fold -s s -l spaces -d 'break lines at word boundaries rather than a hard cut-off'
complete -c uu-fold -s h -l help -d 'Print help'
complete -c uu-fold -s V -l version -d 'Print version'
