complete -c uu-sync -s f -l file-system -d 'sync the file systems that contain the files (Linux and Windows only)'
complete -c uu-sync -s d -l data -d 'sync only file data, no unneeded metadata (Linux only)'
complete -c uu-sync -s h -l help -d 'Print help'
complete -c uu-sync -s V -l version -d 'Print version'
