complete -c uu-coreutils -n "__fish_use_subcommand" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "arch" -d 'Display machine architecture'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "base32" -d 'encode/decode data and print to standard output
With no FILE, or when FILE is -, read standard input.

The data are encoded as described for the base32 alphabet in RFC 4648.
When decoding, the input may contain newlines in addition
to the bytes of the formal base32 alphabet. Use --ignore-garbage
to attempt to recover from any other non-alphabet bytes in the
encoded stream.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "base64" -d 'encode/decode data and print to standard output
With no FILE, or when FILE is -, read standard input.

The data are encoded as described for the base32 alphabet in RFC 4648.
When decoding, the input may contain newlines in addition
to the bytes of the formal base32 alphabet. Use --ignore-garbage
to attempt to recover from any other non-alphabet bytes in the
encoded stream.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "basename" -d 'Print NAME with any leading directory components removed
If specified, also remove a trailing SUFFIX'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "basenc" -d 'Encode/decode data and print to standard output
With no FILE, or when FILE is -, read standard input.

When decoding, the input may contain newlines in addition to the bytes of
the formal alphabet. Use --ignore-garbage to attempt to recover
from any other non-alphabet bytes in the encoded stream.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "cat" -d 'Concatenate FILE(s), or standard input, to standard output
With no FILE, or when FILE is -, read standard input.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "chgrp" -d 'Change the group of each FILE to GROUP.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "chmod" -d 'Change the mode of each FILE to MODE.
With --reference, change the mode of each FILE to that of RFILE.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "chown" -d 'Change file owner and group'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "chroot" -d 'Run COMMAND with root directory set to NEWROOT.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "cksum" -d 'Print CRC and size for each file'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "comm" -d 'Compare two sorted files line by line.

When FILE1 or FILE2 (not both) is -, read standard input.

With no options, produce three-column output. Column one contains
lines unique to FILE1, column two contains lines unique to FILE2,
and column three contains lines common to both files.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "cp" -d 'Copy SOURCE to DEST, or multiple SOURCE(s) to DIRECTORY.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "csplit" -d 'Split a file into sections determined by context lines'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "cut" -d 'Prints specified byte or field columns from each line of stdin or the input files'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "date" -d 'Print or set the system date and time'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "dd" -d 'Copy, and optionally convert, a file system resource'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "df" -d 'Show information about the file system on which each FILE resides,
or all file systems by default.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "dir" -d 'List directory contents.
Ignore files and directories starting with a \'.\' by default'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "dircolors" -d 'Output commands to set the LS_COLORS environment variable.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "dirname" -d 'Strip last component from file name'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "du" -d 'Estimate file space usage'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "echo" -d 'Display a line of text'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "env" -d 'Set each NAME to VALUE in the environment and run COMMAND'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "expand" -d 'Convert tabs in each `FILE` to spaces, writing to standard output.
With no `FILE`, or when `FILE` is `-`, read standard input.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "expr" -d 'Print the value of `EXPRESSION` to standard output'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "factor" -d 'Print the prime factors of the given NUMBER(s).
If none are specified, read from standard input.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "false" -d 'Returns false, an unsuccessful exit status.

Immediately returns with the exit status `1`. When invoked with one of the recognized options it
will try to write the help or version text. Any IO error during this operation is diagnosed, yet
the program will also return `1`.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "fmt" -d 'Reformat paragraphs from input files (or stdin) to stdout.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "fold" -d 'Writes each file (or standard input if no files are given)
to standard output whilst breaking long lines'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "groups" -d 'Print group memberships for each `USERNAME` or, if no `USERNAME` is specified, for
the current process (which may differ if the groups data‐base has changed).'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "hashsum" -d 'Compute and check message digests.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "md5sum" -d 'Compute and check message digests.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "sha1sum" -d 'Compute and check message digests.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "sha224sum" -d 'Compute and check message digests.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "sha256sum" -d 'Compute and check message digests.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "sha384sum" -d 'Compute and check message digests.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "sha512sum" -d 'Compute and check message digests.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "sha3sum" -d 'Compute and check message digests.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "sha3-224sum" -d 'Compute and check message digests.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "sha3-256sum" -d 'Compute and check message digests.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "sha3-384sum" -d 'Compute and check message digests.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "sha3-512sum" -d 'Compute and check message digests.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "shake128sum" -d 'Compute and check message digests.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "shake256sum" -d 'Compute and check message digests.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "b2sum" -d 'Compute and check message digests.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "b3sum" -d 'Compute and check message digests.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "head" -d 'Print the first 10 lines of each `FILE` to standard output.
With more than one `FILE`, precede each with a header giving the file name.
With no `FILE`, or when `FILE` is `-`, read standard input.

Mandatory arguments to long flags are mandatory for short flags too.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "hostid" -d 'Print the numeric identifier (in hexadecimal) for the current host'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "hostname" -d 'Display or set the system\'s host name.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "id" -d 'Print user and group information for each specified `USER`,
or (when `USER` omitted) for the current user.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "install" -d 'Copy SOURCE to DEST or multiple SOURCE(s) to the existing
DIRECTORY, while setting permission modes and owner/group'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "join" -d 'For each pair of input lines with identical join fields, write a line to
standard output. The default join field is the first, delimited by blanks.

When `FILE1` or `FILE2` (not both) is `-`, read standard input.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "kill" -d 'Send signal to processes or list information about signals.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "link" -d 'Call the link function to create a link named FILE2 to an existing FILE1.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "ln" -d 'Change file owner and group'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "logname" -d 'Print user\'s login name'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "ls" -d 'List directory contents.
Ignore files and directories starting with a \'.\' by default'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "mkdir" -d 'Create the given DIRECTORY(ies) if they do not exist'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "mkfifo" -d 'Create a FIFO with the given name.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "mknod" -d 'Create the special file NAME of the given TYPE.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "mktemp" -d 'Create a temporary file or directory.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "more" -d 'Display the contents of a text file'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "mv" -d 'Move `SOURCE` to `DEST`, or multiple `SOURCE`(s) to `DIRECTORY`.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "nice" -d 'Run `COMMAND` with an adjusted niceness, which affects process scheduling.
With no `COMMAND`, print the current niceness.  Niceness values range from at
least -20 (most favorable to the process) to 19 (least favorable to the
process).'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "nl" -d 'Number lines of files'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "nohup" -d 'Run COMMAND ignoring hangup signals.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "nproc" -d 'Print the number of cores available to the current process.
If the `OMP_NUM_THREADS` or `OMP_THREAD_LIMIT` environment variables are set, then
they will determine the minimum and maximum returned value respectively.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "numfmt" -d 'Convert numbers from/to human-readable strings'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "od" -d 'Dump files in octal and other formats'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "paste" -d 'Write lines consisting of the sequentially corresponding lines from each
`FILE`, separated by `TAB`s, to standard output.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "pathchk" -d 'Check whether file names are valid or portable'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "pinky" -d 'Displays brief user information on Unix-based systems'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "pr" -d 'Write content of given file or standard input to standard output with pagination filter'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "printenv" -d 'Display the values of the specified environment VARIABLE(s), or (with no VARIABLE) display name and value pairs for them all.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "printf" -d 'Print output based off of the format string and proceeding arguments.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "ptx" -d 'Produce a permuted index of file contents
Output a permuted index, including context, of the words in the input files.
Mandatory arguments to long options are mandatory for short options too.
With no FILE, or when FILE is -, read standard input. Default is \'-F /\'.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "pwd" -d 'Display the full filename of the current working directory.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "readlink" -d 'Print value of a symbolic link or canonical file name.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "realpath" -d 'Print the resolved path'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "rm" -d 'Remove (unlink) the FILE(s)'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "rmdir" -d 'Remove the DIRECTORY(ies), if they are empty.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "seq" -d ''
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "shred" -d 'Overwrite the specified FILE(s) repeatedly, in order to make it harder for even
very expensive hardware probing to recover the data.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "shuf" -d 'Shuffle the input by outputting a random permutation of input lines.
Each output permutation is equally likely.
With no FILE, or when FILE is -, read standard input.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "sleep" -d 'Pause for NUMBER seconds.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "sort" -d 'Display sorted concatenation of all FILE(s). With no FILE, or when FILE is -, read standard input.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "split" -d 'Create output files containing consecutive or interleaved sections of input'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "stat" -d 'Display file or file system status.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "stdbuf" -d 'Run `COMMAND`, with modified buffering operations for its standard streams.

Mandatory arguments to long options are mandatory for short options too.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "sum" -d 'Checksum and count the blocks in a file.

With no FILE, or when FILE is -, read standard input.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "sync" -d 'Synchronize cached writes to persistent storage'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "tac" -d 'Write each file to standard output, last line first.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "tail" -d 'Print the last 10 lines of each FILE to standard output.
With more than one FILE, precede each with a header giving the file name.
With no FILE, or when FILE is -, read standard input.

Mandatory arguments to long flags are mandatory for short flags too.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "tee" -d 'Copy standard input to each FILE, and also to standard output.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "timeout" -d 'Start `COMMAND`, and kill it if still running after `DURATION`.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "touch" -d 'Update the access and modification times of each `FILE` to the current time.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "tr" -d 'Translate or delete characters'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "true" -d 'Returns true, a successful exit status.

Immediately returns with the exit status `0`, except when invoked with one of the recognized
options. In those cases it will try to write the help or version text. Any IO error during this
operation causes the program to return `1` instead.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "truncate" -d 'Shrink or extend the size of each file to the specified size.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "tsort" -d 'Topological sort the strings in FILE.
Strings are defined as any sequence of tokens separated by whitespace (tab, space, or newline), ordering them based on dependencies in a directed acyclic graph (DAG). 
Useful for scheduling and determining execution order.
If FILE is not passed in, stdin is used instead.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "tty" -d 'Print the file name of the terminal connected to standard input.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "uname" -d 'Print certain system information. 
With no OPTION, same as -s.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "unexpand" -d 'Convert blanks in each `FILE` to tabs, writing to standard output.
With no `FILE`, or when `FILE` is `-`, read standard input.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "uniq" -d 'Report or omit repeated lines.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "unlink" -d 'Unlink the file at `FILE`.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "uptime" -d 'Display the current time, the length of time the system has been up,
the number of users on the system, and the average number of jobs
in the run queue over the last 1, 5 and 15 minutes.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "users" -d 'Print the user names of users currently logged in to the current host.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "test" -d 'Check file types and compare values.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "[" -d 'Check file types and compare values.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "vdir" -d 'List directory contents.
Ignore files and directories starting with a \'.\' by default'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "wc" -d 'Display newline, word, and byte counts for each FILE, and a total line if
more than one FILE is specified. With no FILE, or when FILE is -, read standard input.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "who" -d 'Print information about users who are currently logged in.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "whoami" -d 'Print the current username.'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "yes" -d 'Repeatedly display a line with STRING (or \'y\')'
complete -c uu-coreutils -n "__fish_use_subcommand" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c uu-coreutils -n "__fish_seen_subcommand_from arch" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from base32" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from base64" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from basename" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from basenc" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from cat" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from chgrp" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from chmod" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from chown" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from chroot" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from cksum" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from comm" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from cp" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from csplit" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from cut" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from date" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from dd" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from df" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from dir" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from dircolors" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from dirname" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from du" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from echo" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from env" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from expand" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from expr" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from factor" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from false" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from fmt" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from fold" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from groups" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from hashsum" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from md5sum" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from sha1sum" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from sha224sum" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from sha256sum" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from sha384sum" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from sha512sum" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from sha3sum" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from sha3-224sum" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from sha3-256sum" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from sha3-384sum" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from sha3-512sum" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from shake128sum" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from shake256sum" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from b2sum" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from b3sum" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from head" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from hostid" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from hostname" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from id" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from install" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from join" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from kill" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from link" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from ln" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from logname" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from ls" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from mkdir" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from mkfifo" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from mknod" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from mktemp" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from more" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from mv" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from nice" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from nl" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from nohup" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from nproc" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from numfmt" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from od" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from paste" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from pathchk" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from pinky" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from pr" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from printenv" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from printf" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from ptx" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from pwd" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from readlink" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from realpath" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from rm" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from rmdir" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from seq" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from shred" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from shuf" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from sleep" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from sort" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from split" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from stat" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from stdbuf" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from sum" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from sync" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from tac" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from tail" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from tee" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from timeout" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from touch" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from tr" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from true" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from truncate" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from tsort" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from tty" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from uname" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from unexpand" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from uniq" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from unlink" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from uptime" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from users" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from test" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from [" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from vdir" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from wc" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from who" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from whoami" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from yes" -s h -l help -d 'Print help'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "arch" -d 'Display machine architecture'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "base32" -d 'encode/decode data and print to standard output
With no FILE, or when FILE is -, read standard input.

The data are encoded as described for the base32 alphabet in RFC 4648.
When decoding, the input may contain newlines in addition
to the bytes of the formal base32 alphabet. Use --ignore-garbage
to attempt to recover from any other non-alphabet bytes in the
encoded stream.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "base64" -d 'encode/decode data and print to standard output
With no FILE, or when FILE is -, read standard input.

The data are encoded as described for the base32 alphabet in RFC 4648.
When decoding, the input may contain newlines in addition
to the bytes of the formal base32 alphabet. Use --ignore-garbage
to attempt to recover from any other non-alphabet bytes in the
encoded stream.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "basename" -d 'Print NAME with any leading directory components removed
If specified, also remove a trailing SUFFIX'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "basenc" -d 'Encode/decode data and print to standard output
With no FILE, or when FILE is -, read standard input.

When decoding, the input may contain newlines in addition to the bytes of
the formal alphabet. Use --ignore-garbage to attempt to recover
from any other non-alphabet bytes in the encoded stream.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "cat" -d 'Concatenate FILE(s), or standard input, to standard output
With no FILE, or when FILE is -, read standard input.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "chgrp" -d 'Change the group of each FILE to GROUP.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "chmod" -d 'Change the mode of each FILE to MODE.
With --reference, change the mode of each FILE to that of RFILE.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "chown" -d 'Change file owner and group'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "chroot" -d 'Run COMMAND with root directory set to NEWROOT.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "cksum" -d 'Print CRC and size for each file'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "comm" -d 'Compare two sorted files line by line.

When FILE1 or FILE2 (not both) is -, read standard input.

With no options, produce three-column output. Column one contains
lines unique to FILE1, column two contains lines unique to FILE2,
and column three contains lines common to both files.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "cp" -d 'Copy SOURCE to DEST, or multiple SOURCE(s) to DIRECTORY.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "csplit" -d 'Split a file into sections determined by context lines'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "cut" -d 'Prints specified byte or field columns from each line of stdin or the input files'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "date" -d 'Print or set the system date and time'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "dd" -d 'Copy, and optionally convert, a file system resource'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "df" -d 'Show information about the file system on which each FILE resides,
or all file systems by default.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "dir" -d 'List directory contents.
Ignore files and directories starting with a \'.\' by default'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "dircolors" -d 'Output commands to set the LS_COLORS environment variable.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "dirname" -d 'Strip last component from file name'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "du" -d 'Estimate file space usage'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "echo" -d 'Display a line of text'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "env" -d 'Set each NAME to VALUE in the environment and run COMMAND'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "expand" -d 'Convert tabs in each `FILE` to spaces, writing to standard output.
With no `FILE`, or when `FILE` is `-`, read standard input.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "expr" -d 'Print the value of `EXPRESSION` to standard output'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "factor" -d 'Print the prime factors of the given NUMBER(s).
If none are specified, read from standard input.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "false" -d 'Returns false, an unsuccessful exit status.

Immediately returns with the exit status `1`. When invoked with one of the recognized options it
will try to write the help or version text. Any IO error during this operation is diagnosed, yet
the program will also return `1`.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "fmt" -d 'Reformat paragraphs from input files (or stdin) to stdout.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "fold" -d 'Writes each file (or standard input if no files are given)
to standard output whilst breaking long lines'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "groups" -d 'Print group memberships for each `USERNAME` or, if no `USERNAME` is specified, for
the current process (which may differ if the groups data‐base has changed).'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "hashsum" -d 'Compute and check message digests.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "md5sum" -d 'Compute and check message digests.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "sha1sum" -d 'Compute and check message digests.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "sha224sum" -d 'Compute and check message digests.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "sha256sum" -d 'Compute and check message digests.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "sha384sum" -d 'Compute and check message digests.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "sha512sum" -d 'Compute and check message digests.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "sha3sum" -d 'Compute and check message digests.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "sha3-224sum" -d 'Compute and check message digests.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "sha3-256sum" -d 'Compute and check message digests.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "sha3-384sum" -d 'Compute and check message digests.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "sha3-512sum" -d 'Compute and check message digests.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "shake128sum" -d 'Compute and check message digests.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "shake256sum" -d 'Compute and check message digests.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "b2sum" -d 'Compute and check message digests.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "b3sum" -d 'Compute and check message digests.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "head" -d 'Print the first 10 lines of each `FILE` to standard output.
With more than one `FILE`, precede each with a header giving the file name.
With no `FILE`, or when `FILE` is `-`, read standard input.

Mandatory arguments to long flags are mandatory for short flags too.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "hostid" -d 'Print the numeric identifier (in hexadecimal) for the current host'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "hostname" -d 'Display or set the system\'s host name.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "id" -d 'Print user and group information for each specified `USER`,
or (when `USER` omitted) for the current user.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "install" -d 'Copy SOURCE to DEST or multiple SOURCE(s) to the existing
DIRECTORY, while setting permission modes and owner/group'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "join" -d 'For each pair of input lines with identical join fields, write a line to
standard output. The default join field is the first, delimited by blanks.

When `FILE1` or `FILE2` (not both) is `-`, read standard input.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "kill" -d 'Send signal to processes or list information about signals.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "link" -d 'Call the link function to create a link named FILE2 to an existing FILE1.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "ln" -d 'Change file owner and group'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "logname" -d 'Print user\'s login name'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "ls" -d 'List directory contents.
Ignore files and directories starting with a \'.\' by default'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "mkdir" -d 'Create the given DIRECTORY(ies) if they do not exist'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "mkfifo" -d 'Create a FIFO with the given name.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "mknod" -d 'Create the special file NAME of the given TYPE.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "mktemp" -d 'Create a temporary file or directory.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "more" -d 'Display the contents of a text file'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "mv" -d 'Move `SOURCE` to `DEST`, or multiple `SOURCE`(s) to `DIRECTORY`.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "nice" -d 'Run `COMMAND` with an adjusted niceness, which affects process scheduling.
With no `COMMAND`, print the current niceness.  Niceness values range from at
least -20 (most favorable to the process) to 19 (least favorable to the
process).'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "nl" -d 'Number lines of files'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "nohup" -d 'Run COMMAND ignoring hangup signals.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "nproc" -d 'Print the number of cores available to the current process.
If the `OMP_NUM_THREADS` or `OMP_THREAD_LIMIT` environment variables are set, then
they will determine the minimum and maximum returned value respectively.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "numfmt" -d 'Convert numbers from/to human-readable strings'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "od" -d 'Dump files in octal and other formats'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "paste" -d 'Write lines consisting of the sequentially corresponding lines from each
`FILE`, separated by `TAB`s, to standard output.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "pathchk" -d 'Check whether file names are valid or portable'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "pinky" -d 'Displays brief user information on Unix-based systems'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "pr" -d 'Write content of given file or standard input to standard output with pagination filter'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "printenv" -d 'Display the values of the specified environment VARIABLE(s), or (with no VARIABLE) display name and value pairs for them all.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "printf" -d 'Print output based off of the format string and proceeding arguments.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "ptx" -d 'Produce a permuted index of file contents
Output a permuted index, including context, of the words in the input files.
Mandatory arguments to long options are mandatory for short options too.
With no FILE, or when FILE is -, read standard input. Default is \'-F /\'.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "pwd" -d 'Display the full filename of the current working directory.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "readlink" -d 'Print value of a symbolic link or canonical file name.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "realpath" -d 'Print the resolved path'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "rm" -d 'Remove (unlink) the FILE(s)'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "rmdir" -d 'Remove the DIRECTORY(ies), if they are empty.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "seq" -d ''
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "shred" -d 'Overwrite the specified FILE(s) repeatedly, in order to make it harder for even
very expensive hardware probing to recover the data.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "shuf" -d 'Shuffle the input by outputting a random permutation of input lines.
Each output permutation is equally likely.
With no FILE, or when FILE is -, read standard input.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "sleep" -d 'Pause for NUMBER seconds.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "sort" -d 'Display sorted concatenation of all FILE(s). With no FILE, or when FILE is -, read standard input.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "split" -d 'Create output files containing consecutive or interleaved sections of input'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "stat" -d 'Display file or file system status.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "stdbuf" -d 'Run `COMMAND`, with modified buffering operations for its standard streams.

Mandatory arguments to long options are mandatory for short options too.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "sum" -d 'Checksum and count the blocks in a file.

With no FILE, or when FILE is -, read standard input.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "sync" -d 'Synchronize cached writes to persistent storage'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "tac" -d 'Write each file to standard output, last line first.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "tail" -d 'Print the last 10 lines of each FILE to standard output.
With more than one FILE, precede each with a header giving the file name.
With no FILE, or when FILE is -, read standard input.

Mandatory arguments to long flags are mandatory for short flags too.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "tee" -d 'Copy standard input to each FILE, and also to standard output.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "timeout" -d 'Start `COMMAND`, and kill it if still running after `DURATION`.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "touch" -d 'Update the access and modification times of each `FILE` to the current time.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "tr" -d 'Translate or delete characters'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "true" -d 'Returns true, a successful exit status.

Immediately returns with the exit status `0`, except when invoked with one of the recognized
options. In those cases it will try to write the help or version text. Any IO error during this
operation causes the program to return `1` instead.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "truncate" -d 'Shrink or extend the size of each file to the specified size.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "tsort" -d 'Topological sort the strings in FILE.
Strings are defined as any sequence of tokens separated by whitespace (tab, space, or newline), ordering them based on dependencies in a directed acyclic graph (DAG). 
Useful for scheduling and determining execution order.
If FILE is not passed in, stdin is used instead.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "tty" -d 'Print the file name of the terminal connected to standard input.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "uname" -d 'Print certain system information. 
With no OPTION, same as -s.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "unexpand" -d 'Convert blanks in each `FILE` to tabs, writing to standard output.
With no `FILE`, or when `FILE` is `-`, read standard input.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "uniq" -d 'Report or omit repeated lines.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "unlink" -d 'Unlink the file at `FILE`.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "uptime" -d 'Display the current time, the length of time the system has been up,
the number of users on the system, and the average number of jobs
in the run queue over the last 1, 5 and 15 minutes.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "users" -d 'Print the user names of users currently logged in to the current host.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "test" -d 'Check file types and compare values.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "[" -d 'Check file types and compare values.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "vdir" -d 'List directory contents.
Ignore files and directories starting with a \'.\' by default'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "wc" -d 'Display newline, word, and byte counts for each FILE, and a total line if
more than one FILE is specified. With no FILE, or when FILE is -, read standard input.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "who" -d 'Print information about users who are currently logged in.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "whoami" -d 'Print the current username.'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "yes" -d 'Repeatedly display a line with STRING (or \'y\')'
complete -c uu-coreutils -n "__fish_seen_subcommand_from help; and not __fish_seen_subcommand_from arch; and not __fish_seen_subcommand_from base32; and not __fish_seen_subcommand_from base64; and not __fish_seen_subcommand_from basename; and not __fish_seen_subcommand_from basenc; and not __fish_seen_subcommand_from cat; and not __fish_seen_subcommand_from chgrp; and not __fish_seen_subcommand_from chmod; and not __fish_seen_subcommand_from chown; and not __fish_seen_subcommand_from chroot; and not __fish_seen_subcommand_from cksum; and not __fish_seen_subcommand_from comm; and not __fish_seen_subcommand_from cp; and not __fish_seen_subcommand_from csplit; and not __fish_seen_subcommand_from cut; and not __fish_seen_subcommand_from date; and not __fish_seen_subcommand_from dd; and not __fish_seen_subcommand_from df; and not __fish_seen_subcommand_from dir; and not __fish_seen_subcommand_from dircolors; and not __fish_seen_subcommand_from dirname; and not __fish_seen_subcommand_from du; and not __fish_seen_subcommand_from echo; and not __fish_seen_subcommand_from env; and not __fish_seen_subcommand_from expand; and not __fish_seen_subcommand_from expr; and not __fish_seen_subcommand_from factor; and not __fish_seen_subcommand_from false; and not __fish_seen_subcommand_from fmt; and not __fish_seen_subcommand_from fold; and not __fish_seen_subcommand_from groups; and not __fish_seen_subcommand_from hashsum; and not __fish_seen_subcommand_from md5sum; and not __fish_seen_subcommand_from sha1sum; and not __fish_seen_subcommand_from sha224sum; and not __fish_seen_subcommand_from sha256sum; and not __fish_seen_subcommand_from sha384sum; and not __fish_seen_subcommand_from sha512sum; and not __fish_seen_subcommand_from sha3sum; and not __fish_seen_subcommand_from sha3-224sum; and not __fish_seen_subcommand_from sha3-256sum; and not __fish_seen_subcommand_from sha3-384sum; and not __fish_seen_subcommand_from sha3-512sum; and not __fish_seen_subcommand_from shake128sum; and not __fish_seen_subcommand_from shake256sum; and not __fish_seen_subcommand_from b2sum; and not __fish_seen_subcommand_from b3sum; and not __fish_seen_subcommand_from head; and not __fish_seen_subcommand_from hostid; and not __fish_seen_subcommand_from hostname; and not __fish_seen_subcommand_from id; and not __fish_seen_subcommand_from install; and not __fish_seen_subcommand_from join; and not __fish_seen_subcommand_from kill; and not __fish_seen_subcommand_from link; and not __fish_seen_subcommand_from ln; and not __fish_seen_subcommand_from logname; and not __fish_seen_subcommand_from ls; and not __fish_seen_subcommand_from mkdir; and not __fish_seen_subcommand_from mkfifo; and not __fish_seen_subcommand_from mknod; and not __fish_seen_subcommand_from mktemp; and not __fish_seen_subcommand_from more; and not __fish_seen_subcommand_from mv; and not __fish_seen_subcommand_from nice; and not __fish_seen_subcommand_from nl; and not __fish_seen_subcommand_from nohup; and not __fish_seen_subcommand_from nproc; and not __fish_seen_subcommand_from numfmt; and not __fish_seen_subcommand_from od; and not __fish_seen_subcommand_from paste; and not __fish_seen_subcommand_from pathchk; and not __fish_seen_subcommand_from pinky; and not __fish_seen_subcommand_from pr; and not __fish_seen_subcommand_from printenv; and not __fish_seen_subcommand_from printf; and not __fish_seen_subcommand_from ptx; and not __fish_seen_subcommand_from pwd; and not __fish_seen_subcommand_from readlink; and not __fish_seen_subcommand_from realpath; and not __fish_seen_subcommand_from rm; and not __fish_seen_subcommand_from rmdir; and not __fish_seen_subcommand_from seq; and not __fish_seen_subcommand_from shred; and not __fish_seen_subcommand_from shuf; and not __fish_seen_subcommand_from sleep; and not __fish_seen_subcommand_from sort; and not __fish_seen_subcommand_from split; and not __fish_seen_subcommand_from stat; and not __fish_seen_subcommand_from stdbuf; and not __fish_seen_subcommand_from sum; and not __fish_seen_subcommand_from sync; and not __fish_seen_subcommand_from tac; and not __fish_seen_subcommand_from tail; and not __fish_seen_subcommand_from tee; and not __fish_seen_subcommand_from timeout; and not __fish_seen_subcommand_from touch; and not __fish_seen_subcommand_from tr; and not __fish_seen_subcommand_from true; and not __fish_seen_subcommand_from truncate; and not __fish_seen_subcommand_from tsort; and not __fish_seen_subcommand_from tty; and not __fish_seen_subcommand_from uname; and not __fish_seen_subcommand_from unexpand; and not __fish_seen_subcommand_from uniq; and not __fish_seen_subcommand_from unlink; and not __fish_seen_subcommand_from uptime; and not __fish_seen_subcommand_from users; and not __fish_seen_subcommand_from test; and not __fish_seen_subcommand_from [; and not __fish_seen_subcommand_from vdir; and not __fish_seen_subcommand_from wc; and not __fish_seen_subcommand_from who; and not __fish_seen_subcommand_from whoami; and not __fish_seen_subcommand_from yes; and not __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
